#
# spec file for package gpxsee
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           gpxsee
Version:        7.28
Release:        lp152.1.2
Summary:        GPS log file visualization and analysis tool
License:        GPL-3.0-only
Group:          Productivity/Graphics/Viewers
Url:            http://www.gpxsee.org
Source0:        GPXSee-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  make
%if 0%{?centos_version} >= 800
BuildRequires:  gdb-headless
%endif
%if 0%{?fedora_version} || 0%{?centos_version} >= 800
BuildRequires:  qt5-qtbase
BuildRequires:  qt5-qtbase-gui
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-linguist
Recommends: qt5-qtimageformats
Recommends: qt5-qtpbfimageformat
%else
%if 0%{?suse_version}
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Concurrent-devel
BuildRequires:  libQt5Gui-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  libQt5Network-devel
BuildRequires:  libQt5PrintSupport-devel
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libQt5Sql-devel
BuildRequires:  libqt5-linguist
Recommends: libQt5Sql5-sqlite
Recommends: libqt5-qtimageformats
Recommends: libqt5-qtpbfimageformat
%else
%if (0%{?rhel_version} && 0%{?rhel_version} < 800) || (0%{?centos_version} && 0%{?centos_version} < 800)
BuildRequires:  libqt4-devel
%else
# Mageia
BuildRequires:  libqt5core-devel
BuildRequires:  libqt5gui-devel
BuildRequires:  libqt5concurrent-devel
BuildRequires:  libqt5widgets-devel
BuildRequires:  libqt5network-devel
BuildRequires:  libqt5printsupport-devel
BuildRequires:  libqt5opengl-devel
BuildRequires:  libqt5sql-devel
BuildRequires:  qttools5
Recommends: qtimageformats5
Recommends: libqt5-database-plugin-sqlite
Recommends: libqt5-qtpbfimageformat
%endif
%endif
%endif

%description
GPXSee is a Qt-based tool for visualizing and analyzing GPX, TCX, FIT, KML,
IGC, CUP, NMEA, SLF, LOC, OziExplorer (PLT, RTE, WPT), Garmin CSV and geotagged
JPEG files.

%prep
%setup -q -n GPXSee-%{version}

%build
%if 0%{?suse_version}
lrelease-qt5 gpxsee.pro
%{qmake5} gpxsee.pro
%else
%if 0%{?fedora_version} || 0%{?centos_version} >= 800
lrelease-qt5 gpxsee.pro
%{qmake_qt5} gpxsee.pro
%else
%if (0%{?rhel_version} && 0%{?rhel_version} < 800) || (0%{?centos_version} && 0%{?centos_version} < 800)
lrelease-qt4 gpxsee.pro
qmake-qt4 PREFIX=/usr gpxsee.pro
%else
lrelease gpxsee.pro
%{qmake_qt5} gpxsee.pro
%endif
%endif
%endif
make %{?_smp_mflags}

%install
install -d 755 %{buildroot}/%{_bindir}
install -d 755 %{buildroot}/%{_datadir}/applications
install -d 755 %{buildroot}/%{_datadir}/pixmaps
install -d 755 %{buildroot}/%{_datadir}/mime/packages
install -d 755 %{buildroot}/%{_datadir}/%{name}
install -d 755 %{buildroot}/%{_datadir}/%{name}/maps
install -d 755 %{buildroot}/%{_datadir}/%{name}/csv
install -d 755 %{buildroot}/%{_datadir}/%{name}/translations
install -m 755 gpxsee %{buildroot}/%{_bindir}/%{name}
install -m 644 pkg/maps/* %{buildroot}/%{_datadir}/%{name}/maps
install -m 644 pkg/csv/* %{buildroot}/%{_datadir}/%{name}/csv
install -m 644 lang/*.qm %{buildroot}/%{_datadir}/%{name}/translations
install -m 644 icons/gpxsee.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png
install -m 644 pkg/gpxsee.desktop %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -m 644 pkg/gpxsee.xml %{buildroot}/%{_datadir}/mime/packages/%{name}.xml

%post
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%postun
if [ -x /usr/bin/update-mime-database ]; then
	/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi
if [ -x /usr/bin/update-desktop-database ]; then
	/usr/bin/update-desktop-database > /dev/null || :
fi

%files
%defattr(-,root,root)
%dir %{_datadir}/gpxsee
%{_bindir}/*
%{_datadir}/%{name}/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*

%changelog
* Sun Apr  5 2020 tumic@cbox.cz
- Update to version 7.28
  * Fixed broken graph color change when secondary graphs present.
  * Fixed broken map enable condition (selecting such map crashes
    GPXSee).
* Sat Mar 28 2020 tumic@cbox.cz
- Update to version 7.27
  * Fixed builds with -Werror=format-security (Fedora, RHEL,
    Mageia). No real issue.
* Sat Mar 28 2020 tumic@cbox.cz
- Update to version 7.26
  * Enable simultaneous display of GPS and DEM data.
  * Asynchronous WMS/WMTS map loading (fixes crash on OS X).
  * Various minor bug fixes.
* Wed Mar  4 2020 tumic@cbox.cz
- Update to version 7.25
  * Added missing OnlineResources URLs handling in WMS maps.
  * A better WMS format parameter handling (partialy broken in
    7.24)
* Sun Mar  1 2020 tumic@cbox.cz
- Update to version 7.24
  * Multiple WMS maps fixes.
* Mon Feb 17 2020 tumic@cbox.cz
- Update to version 7.23
  * Fixed various IMG maps rendering issues.
  * Improved the default IMG map style.
* Thu Feb 13 2020 tumic@cbox.cz
- Update to version 7.22
  * Fixed loading of GMAP maps when Garmin BaseCamp has associated
    them (OS X issue).
* Wed Feb 12 2020 tumic@cbox.cz
- Update to version 7.21
  * Added support for Garmin GMAP maps.
  * Various IMG/GMAP maps fixes/improvements.
  * Hungarian localization.
* Sun Jan 26 2020 tumic@cbox.cz
- Update to version 7.20
  * Added support for Suunto SML files.
  * Various IMG maps improvements.
* Sun Jan 12 2020 tumic@cbox.cz
- Update to version 7.19
  * Fixed/improved pause detection.
  * Fixed buffer overflow in GPI parser.
  * OpenStreetMap and 4UMaps URL changes.
  * Minor IMG file format reader fixes/improvements.
  * Fixed/improved tooltip/popups handling.
  * Translations updates.
* Fri Nov 15 2019 tumic@cbox.cz
- Update to version 7.18
  * Added support for waypoint addresses.
  * Improved pause detection.
  * Improved GPI support (images, safety cameras).
  * Added Ukrainian translation.
* Sat Nov  2 2019 tumic@cbox.cz
- Update to version 7.17
  * Fixed program crash on empty GPX segment.
  * Fixed broken DEM value reading on S/W coordinates.
  * Various GPI parser fixes & improvements.
* Mon Oct 28 2019 tumic@cbox.cz
- Update to version 7.16
  * Added support for Garmin GPI files.
  * Hyperlink + copy&paste enabled tool tips.
  * Various minor bug fixes in data loading.
* Sat Oct  5 2019 tumic@cbox.cz
- Update to version 7.15
  * Fixed broken align of zoom level 0 with tiles of a different
    size than 256px.
  * Increased the default tile cache size value to 256MB.
  * IMG maps text layout tweaking and optimization.
* Sun Sep 29 2019 tumic@cbox.cz
- Update to version 7.14
  * Added support for enchanced altitude and speed records in FIT
    files.
  * Added support for pseudo-NT IMG maps (e.g. TopoHispania).
* Sun Sep  1 2019 tumic@cbox.cz
- Update to version 7.13
  * Added support for graph zooming.
  * Several minor bug fixes.
* Sat Aug 17 2019 tumic@cbox.cz
- Update to version 7.12
  * Added support for SeeYou CUP files.
  * Added support for Geographic 2D projection in vector maps.
  * Fixed lat/lon reference parsing in big endian EXIF entries.
* Thu Jul 18 2019 tumic@cbox.cz
- Update to version 7.11
  * Improved IMG maps loading performance and memory footprint.
  * Improved road shields layout on IMG maps.
* Sun Jul  7 2019 tumic@cbox.cz
- Update to version 7.10
  * Various IMG maps fixes and improvements.
* Sat Jun 15 2019 tumic@cbox.cz
- Update to version 7.9
  * Removed the annoying map view re-zooming on window resize.
  * Improved POI handling and text rendering in IMG maps.
* Thu May 30 2019 tumic@cbox.cz
- Update to version 7.8
  * Added support for QuadTiles maps.
  * Added (optional) km/mi path markers.
  * Fixed broken IMG maps after print/PDF export.
  * Fixed broken zoom fit on IMG maps.
  * Fixed broken WMS scale denominators to zoom levels transition.
* Sat May 18 2019 tumic@cbox.cz
- Update to version 7.7
  * Fixed build & display issues with Qt < 5.4.
  * Added support for vector maps projection setting.
  * Added support for user defined TYP files for Garmin IMG maps.
  * Removed obsolete "Always show the map" setting.
* Sun May 12 2019 tumic@cbox.cz
- Update to version 7.6
  * Added support for Garmin IMG maps.
  * Fixed coordinates info display issues.
  * Fixed rendering of large areas using OpenGL.
  * Fixed broken speed type switch.
* Sat Mar 16 2019 tumic@cbox.cz
- Update to version 7.5
  * Added support for geotagged JPEG images.
* Sun Mar 10 2019 tumic@cbox.cz
- Update to version 7.4
  * Added support for TwoNav RMaps.
  * Fixed broken projection equations (multiple corner cases).
  * Fixed IGC date handling issues.
* Tue Feb 19 2019 tumic@cbox.cz
- Update to version 7.3
  * Added support for area (polygon) objects.
  * Added support for track segments.
  * Added support for oblique stereographic projections.
  * Added the "Show cursor coordinates" option.
  * Added Portuguese (Brazil) localization.
  * Minor bug fixes (GPX parser, GUI).
* Mon Jan 28 2019 tumic@cbox.cz
- Update to version 7.2
  * Added support for DEM data (SRTM HGT files).
  * Improved look&feel in dark styles.
  * Added support for polar stereographic projections + Antarctica
    map.
  * Added support for GeoJSON files.
  * Added Spanish localization.
* Wed Jan  2 2019 tumic@cbox.cz
- Update to version 7.1
  * Fixed build with Qt5 <= 5.4
  * Minor bug fixes & updates (TCX, localization)
* Sat Dec  8 2018 tumic@cbox.cz
- Update to version 7.0
  * Added support for PBF vector maps (requires QtPbfImagePlugin).
  * Changed user data/config paths locations.
  * Added Turkish localization.
  * Minor bug fixes (WMTS, graphs)
* Sat Oct 13 2018 tumic@cbox.cz
- Update to version 6.3
  * Fixed broken OSM maps non-default bounds handling.
  * Fixed broken cleanup on exit (introduced in 6.1).
  * Added Danish localization.
* Sun Oct  7 2018 tumic@cbox.cz
- Update to version 6.2
  * Fixed Norwegian localization language code.
* Sun Oct  7 2018 tumic@cbox.cz
- Update to version 6.1
  * Fixed broken tiles rendering on OSM/TMS map borders (broken in
    5.18).
  * Fixed "enable HTTP2" configuration handling.
  * Added Norwegian localization.
* Sun Sep 23 2018 tumic@cbox.cz
- Update to version 6.0
  * Added MBTiles maps support.
  * Added TMS maps support.
  * Added support for local file URLs (OSM, TMS, WMTS maps).
  * Minor bugfixes (localization, WMTS, date-line crossing).
* Sat Sep 15 2018 tumic@cbox.cz
- Update to version 5.18
  * Made the HiDPI display mode (of non-HiDPI maps) configurable.
  * Long path segments now displayed using great circle paths.
  * Fixed IGC parser (new date header format support).
  * Fixed broken zoom level 0 handling.
  * Fixed POI search algorithm.
  * Fixed Garmin CSV parser (wrong coordinates order).
  * Some more minor bugfixes.
* Sat Aug 18 2018 tumic@cbox.cz
- Update to version 5.17
  * Added support for HiDPI/Retina displays & maps.
  * Added support for SIGMA SPORT SLF files.
  * Added support for Geocaching.com LOC files.
* Wed Aug  8 2018 jengelh@inai.de
- Fixup grammar of summary.
* Wed Aug  8 2018 tumic@cbox.cz
- Update to version 5.16
  * Added statistics report.
  * Added support for HTTP/2 (Qt>=5.10.1)
  * Various minor bugfixes.
* Tue Jul  3 2018 tumic@cbox.cz
- Update to version 5.15
  * Added gear ratio/shifts graphs (Shimano Di2).
  * Fixed FIT parser crash.
  * Added support for obscure Bryton Rider FIT files.
  * Some more minor bugfixes.
* Sat Jun 23 2018 tumic@cbox.cz
- Update to version 5.14
  * Improved outlier detection (now based on acceleration rather
    than speed)
  * Fixed broken distance computation when outlier detection was
    enabled.
  * Added speed data source setting.
  * Several minor bugfixes.
* Tue May 29 2018 tumic@cbox.cz
- Update to version 5.13
  * Fixed broken automatic loading of OziExplorer maps (introduced
    in 5.12)
  * Added support for Krovak projections (EPSG:1041 and EPSG:9819)
* Fri May 25 2018 tumic@cbox.cz
- Update to version 5.12
  * Added support for Garmin JNX maps.
  * Added support for GPX Garmin route extension.
  * Several performance improvements.
* Mon May 14 2018 tumic@cbox.cz
- Update to version 5.11
  * Added support for EPSG:9606 and 9607 datum transformations.
  * Added support for Mercator projection (the real one).
  * Updated the GCS & PCS files.
  * Fixed LCC2 GeoTIFF images loading.
  * Fixed broken time-based graphs for files with duplicit
    timestamps.
* Wed May  9 2018 tumic@cbox.cz
- Update to version 5.10
  * Improved track loading performance.
  * Improved network/server error handling.
  * Added missing EST97 GCS/PCS.
  * Several minor bugfixes and improvements.
* Thu Apr 19 2018 tumic@cbox.cz
- Update to version 5.9
  * Fixed HTTP redirects handling.
  * Proper fix of the zoom changes/offset bugs (resolved only
    partialy in 5.8).
* Wed Apr 18 2018 tumic@cbox.cz
- Update to version 5.8
  * Fixed the irritating map zoom changes on OSM maps switching and
    the 1px map center offset bug.
  * Added Polish translation.
* Tue Apr 17 2018 tumic@cbox.cz
- Update to version 5.7
  * Added OziExplorer data files (plt, rte, wpt) support.
* Sun Apr  8 2018 tumic@cbox.cz
- Update to version 5.6
  * Added WMS support.
  * Several minor bugfixes and improvements (mostly WMTS).
* Tue Mar 20 2018 tumic@cbox.cz
- Update to version 5.5
  * Fixed deadlocks caused by infinite HTTP timeout.
  * Several minor bugfixes.
* Sun Mar 11 2018 tumic@cbox.cz
- Update to version 5.4
  * Added pace info.
  * Added support for EPSG 21781 PCS (Swiss grid).
  * Added missing WMTS dimensions handling.
  * Fixed broken zoom rectangle computation.
  * Fixed swapped GeoTIFF LCC1 and LCC2 projection codes.
  * Fixed loading of WGS84 GeoTIFF images defined using
    the ellipsoid only.
  * Fixed broken (case-sensitive) WMTS parameters handling.
* Thu Mar  1 2018 tumic@cbox.cz
- Update to version 5.3
  * Added support for WMTS maps.
  * Fixed Lambert azimuthal equal area projection.
  * Improved scale computation on offline maps.
  * Added some more GCS/PCS definitions.
  * Fixed invalid memory access.
* Sat Feb 17 2018 tumic@cbox.cz
- Update to version 5.2
  * Fixed broken GeoTIFF (Web) Mercator projection.
  * Several minor bug fixes.
* Mon Feb 12 2018 tumic@cbox.cz
- Update to version 5.1
  * Fixed crash during static data initialization.
  * Added coordinates format setting.
  * Added nautical units setting.
* Sat Feb 10 2018 tumic@cbox.cz
- Update to version 5.0
  * Added support for GeoTIFF images.
  * Online map sources are now defined using XML files.
  * Added Finnish, French and Russian localization.
* Mon Jan  8 2018 tumic@cbox.cz
- Update to version 4.19
  * Fixed missing cached content cleanup causing huge draw areas
    (causing system memory exhaustion) issue.
* Sat Jan  6 2018 tumic@cbox.cz
- Update to version 4.18
  * Fixed broaken A records parsing in IGC files.
  * Added support for negative altitudes in IGC files.
* Sat Dec  9 2017 tumic@cbox.cz
- Update to version 4.17
  * Added support for Lambert Azimuthal Equal Area projections.
  * Added support for map viewing without GPS log files loaded.
  * Added slider/marker color setting.
  * Fixed scene centering issue.
  * Fixed offline map scale computation issue.
  * Fixed some corner case map drawing issues.
* Wed Oct 18 2017 tumic@cbox.cz
- Update to version 4.16
  * Fixed broken loading of KML files with folder elements outside
    document element.
  * Added support for KML files with multitracks.
  * Added support for Temperature, Cadence and Heartrate in KML
    files.
  * Added support for TCX multi-sport activities.
* Fri Oct  6 2017 tumic@cbox.cz
- Update to version 4.15
  * Fixed the 1px content offset on zoom/map change issue.
  * Improved graph slider info.
  * Graph items are now selecteble like path items (+ tool tips).
* Fri Sep 15 2017 tumic@cbox.cz
- Update to version 4.14
  * Fixed broken parsing of TCX files with heart rate data.
  * Fixed invalid memory access in NMEA parser.
  * Fixed broken units setting for cadence, heart rate and power
    graphs.
  * Added support for limiting the maximal zoom level of online map
    sources.
  * Added waypoints/POI size/color settings and map background
    color settings.
  * Adjusted the scale bar (text) size to the remaining content
    in print/PDF export output.
* Sun Sep  3 2017 tumic@cbox.cz
- Update to version 4.13
  * Added support for high-resolution printing.
* Thu Aug 24 2017 tumic@cbox.cz
- Update to version 4.12
  * Fixed broken LCC projection on southern hemisphere.
  * Added support for France I-IV and VICGRID/VICGRID94 projections.
  * Added map opacity (brightness) setting.
  * Added 4UMaps to map sources.
* Tue Aug 15 2017 tumic@cbox.cz
- Update to version 4.11
  * Fixed QT4 build.
* Tue Aug 15 2017 tumic@cbox.cz
- Update to version 4.10
  * Added support for OZF zoom levels.
  * Added support for maps with only 2 reference points.
  * Various map loading/displaying improvements.
* Tue Jul 11 2017 tumic@cbox.cz
- Update to version 4.9
  * Improved map switching (no more track resizing on map change).
  * Improved TARed Trekbuddy maps loading (now using TMI index
    files if available).
  * Optimized POI handling.
* Thu May 25 2017 tumic@cbox.cz
- Update to version 4.8
  * Added data filtering settings.
  * Fixed broken units handling in track info tooltips.
* Tue May  9 2017 tumic@cbox.cz
- Update to version 4.7
  * Fixed broken offline maps on southern hemisphere.
  * Fixed broken UTM zone setup on some offline maps.
  * Added support for OZF3 files.
  * Added support for Albers Equal-Area projection.
  * Added support for offline maps with projections defined as
    British, Irish and Swedish grid and NZTM2000.
* Tue May  2 2017 tumic@cbox.cz
- Update to version 4.6
  * Fixed broken PDF export/printing (broken map scale/waypoints
    size).
  * Improved path projection performance when an atlas is used.
* Sun Apr 23 2017 tumic@cbox.cz
- Update to version 4.5
  * Added support for "runtime" loading of offline maps.
  * Fixed atlas zoom fitting.
  * Fixed various minor offline map loading issues.
* Mon Apr 17 2017 tumic@cbox.cz
- Update to version 4.4
  * Added support for ozf2 image files.
  * Added full support for non-WGS84 datum based offline maps.
  * Added German localization.
* Wed Apr 12 2017 tumic@cbox.cz
- Update to version 4.3
  * Fixed missing cached content cleanup causing huge draw areas
    (causing memory exhaustion) issue.
  * Fixed map file defined datum not set for UTM maps issue.
* Thu Apr  6 2017 tumic@cbox.cz
- Update to version 4.2
  * Added digital zoom.
  * Fixed atlas map fitting algorithm.
  * Completed Swedish translation.
* Sun Apr  2 2017 tumic@cbox.cz
- Update to version 4.1
  * Added support for Lambert conformal conic projection.
* Sat Apr  1 2017 tumic@cbox.cz
- Update to version 4.0
  * Added support for offline maps.
  * Fixed zoom issues on touchpads.
* Mon Feb 13 2017 tumic@cbox.cz
- Update to version 3.9
  * Fixed broken POI radius computation.
  * Added moving time info.
  * Improved pause detection/handling.
* Tue Jan 24 2017 tumic@cbox.cz
- Update to version 3.8
  * Fixed graph info not redrawing issue.
  * Added Swedish localization.
* Mon Jan 23 2017 tumic@cbox.cz
- Update to version 3.7
  * Fixed tile downloading issues (multiple downloads, redirect
    loop).
  * Enabled free map scroll.
* Tue Dec 20 2016 tumic@cbox.cz
- Update to version 3.5
  * Fixed broken NMEA latitude parsing.
  * Added print/export options.
* Sat Dec 10 2016 tumic@cbox.cz
- Update to version 3.4
  * Fixed QT5 < 5.4 builds (Debian 8).
* Fri Dec  9 2016 tumic@cbox.cz
- Update to version 3.3
  * Added options dialog with basic appearance settings.
  * Added OpenGL support.
* Tue Nov 22 2016 tumic@cbox.cz
- Update to version 3.2
  * Added support for NMEA files.
  * Fixed path marker inaccuracy bug.
* Sat Nov 12 2016 tumic@cbox.cz
- Update to version 3.1
  * Added support for IGC files.
  * Fixed zoom level computation bugs.
* Mon Nov  7 2016 tumic@cbox.cz
- Update to version 3.0
  * Added support for TCX, KML and FIT files.
  * Added cadence and power graphs.
  * Improved outlier detection (now also applies to track points).
  * GUI polishing.
  * Improved print output.
* Sun Oct 16 2016 tumic@cbox.cz
- Update to version 2.20
  * Added support for drag&drop.
  * Fixed graph line distortion in PDF output.
  * Fixed POI loading performance issue.
  * GUI polishing.
* Wed Sep 28 2016 tumic@cbox.cz
- Update to version 2.19
  * Added time-based graphs.
  * Added track/graph highlighting (on track hover).
  * Added support for proxy connections (using the system-defined
    proxy).
  * Fixed PDF output in QT4 builds.
* Wed Aug 31 2016 tumic@cbox.cz
- Update to version 2.18
  * Added support for GPX routes.
  * Added various data display options.
  * Improved performance.
* Wed Aug  3 2016 tumic@cbox.cz
- Update to version 2.17
  * Added waypoint/track info tooltips.
  * Improved POI handling.
* Thu Jun 16 2016 tumic@cbox.cz
- Update to version 2.16
  * Fixed infinite download loop on HTTP redirects (and broken
    images).
  * Fixed handling of GPX files with inconsistent track point
    entries.
  * Added support for temperature graphs.
* Sat May 28 2016 tumic@cbox.cz
- Update to version 2.14
  * Added print support.
  * Many fixes & improvements in PDF export (e.g. map support).
* Tue May  3 2016 tumic@cbox.cz
- Update to version 2.13
  * Fixed broken opening of non-ASCII named files as program
    arguments.
  * File info in window title.
  * Persistent program settings.
* Thu Apr 14 2016 tumic@cbox.cz
- Update to version 2.12
  * Added fullscreen mode.
  * Polished GUI.
* Sat Apr  2 2016 tumic@cbox.cz
- Update to version 2.11
  * Added "clear tile cache" option.
  * Lots of minor bug fixes and enhancements.
* Fri Mar 25 2016 tumic@cbox.cz
- Update to version 2.10
  * Added heart rate graphs.
  * Polished GUI.
  * Redesigned map/POI data sources handling.
  * Lots of minor bug fixes and enhancements.
* Sun Mar 20 2016 tumic@cbox.cz
- Update to version 2.9
  * Added support for displaying waypoints.
  * Minor bug fixes and enhancements.
* Sun Mar  6 2016 tumic@cbox.cz
- Update to version 2.8
  * Improved POI files control.
  * Minor bug fixes and enhancements.
* Sat Feb 13 2016 tumic@cbox.cz
- Update to version 2.7
  * Added default map sources (OSM, Thunderforest).
  * Added support for POIs in GPX format.
  * Added support for GPX files with multiple tracks.
* Wed Feb  3 2016 tumic@cbox.cz
- Update to version 2.6
  * Added map scale info.
  * Improved PDF export.
* Sun Dec 20 2015 tumic@cbox.cz
- Update to version 2.5
  * Added support for imperial units.
  * Fixed track view resizing issues.
